@@ -139,29 +139,45 @@ var displayPanel = {
 	    
 	    $('ul.blocked-js').empty();
 	    $('ul.accepted-js').empty();
-	    
+
+
 	    removedLen = message.urlData.removed.length;
 	    acceptedLen = message.urlData.accepted.length;
 	    
 	    if (removedLen > 0) {
+
 		for (var i = 0; i < removedLen; i++) {
+
 		    this.button1.fadeIn();
 		    li = this.formatListScript(message.urlData.removed[i]);
 		    $('ul.blocked-js').append(li);
+
 		}
-	    } else {
+
+	    } 
+	    
+	    else {
+
 		this.button1.hide();
+
 		$('ul.blocked-js').append('<li>LibreJS did not block any script on this page: \n\n<ul><li>There may be no script on this page (check source, C-u).</li><li>All the scripts on this page may be trivial and/or free.</li><li>You may have whitelisted this domain name or url from the preferences (Type about:addons in your location bar to check)</li><li>You may have clicked the "allow all scripts" button, which causes LibreJS to load all JavaScript on a page regardless of whether it is free, trivial, nontrivial or nonfree. This policy is effective for the entire duration of a Firefox session.</li><li>If for any reason you think LibreJS should have blocked JavaScript code on this page, please report this issue to: <a id="report" href="" target="_blank">lduros@gnu.org</a></li></ul></li>');
+
 		$('#report').attr('href', 'mailto:lduros@gnu.org?subject=LibreJS bug Report&body=LibreJS issue with page: ' + message.pageURL);
+
 	    }
 
 	    // get accepted scripts.
 	    $('h2.accepted-js').html("List of <span class='accepted'>accepted</span> JS in " + $('<div/>').text(message.pageURL).html());
+
 	    if (acceptedLen > 0) {
+
 		for (var i = 0; i < acceptedLen; i++) {
+
 		    li = this.formatListScript(message.urlData.accepted[i]);
 		    $('ul.accepted-js').append(li);
+
 		}
+
 	    }
 
 	    $('#info').animate({opacity: 1});
