@@ -38,19 +38,10 @@ const prompt = Cc["@mozilla.org/embedcomp/prompt-service;1"].
 
 const tabs = require('tabs');
 
-var clearCache;
-
 // check if there's an update on gnu.org.
 // provide a link in widget panel if there is an update.
 var update = require('addon_management/update');
 
-var clearAndReloadAll = function () {
-    caching.clearAllCache();
-    for each (var tab in tabs) {
-	tab.reload();
-    }
-};
-
 /**
  * Stop the httpObserver when the add-on
  * is disabled or removed.
@@ -72,11 +63,11 @@ exports.onUnload = function(reason) {
 
 exports.onLoad = function () {
     try {
-    var clearCache = prompt.confirm(null, "LibreJS installation", "In order to analyze the pages you have already loaded, LibreJS must reload all your tabs and windows.\n\nIf you have many tabs opened, it can take long and slow down your browser. If you only have a few tabs opened, click 'OK' to reload them; if you have many tabs opened, click 'Cancel' and refresh the tabs you are using manually.");
+    var clearCache = prompt.confirm(null, "LibreJS installation", "In order for LibreJS to work properly, you should clear the browser cache.\nIf you have tabs and windows opened prior to installing LibreJS, you will have to refresh them for their JavaScript to be analyzed and blocked. Press OK to clear the browser cache.");
     if (clearCache) {
-	clearAndReloadAll();
+	caching.clearAllCache();
     }
     } catch (e) {
 	console.log(e);
     }
-}
\ No newline at end of file
+};
\ No newline at end of file
