@@ -169,6 +169,9 @@ var domHandlerObject = {
 	// initialize object properties.
 	
 	//console.log('init', pageURL);
+	var that = this;
+
+	this.reset();
 
 	// arguments passed.
 	this.dom = domObject;
@@ -176,19 +179,30 @@ var domHandlerObject = {
 	this.fragment = fragment;
 	this.responseStatus = responseStatus;
 
+
+
 	//console.log('in dom handler, responseStatus is', this.responseStatus);
 
 	// make callback function available
 	// for the entire object.
-	this.callback = callback;
+	this.callback = function (dom) { 
+	    callback(dom);
+	    that.destroy();
+	}; 
 
+
+
+    },
+    reset: function () {
+
+	this.dom = null;
 	// arrays.
 	this.onEventElement = [];
 	this.scriptStatus = [];
 	this.inlineScripts = [];
 	this.externalScripts = [];
 	this.scripts = [];
-
+	 
 	// booleans
 	this.allowTrivial = true;
 	this.inlineJsFree = false;
@@ -203,10 +217,15 @@ var domHandlerObject = {
 
 	this.scriptsTested = 0;
 
-	this.licenseList = [];
 
     },
 
+    destroy: function () {
+	this.domGatherer = null;
+	this.domChecker = null;
+	//this.reset();
+    },
+
     scriptHasBeenTested: function () {
 	this.scriptsTested++;
     },
@@ -302,7 +321,7 @@ var domHandlerObject = {
 
 	    
 	} catch (x) {
-	    console.log('error', x);
+	    console.log('error', x, x.lineNumber, x.fileName);
 	}
 
 
@@ -388,7 +407,7 @@ var domHandlerObject = {
 	    }
 	}
 
-    },    
+    }, 
 
     /**
      * removeGivenJs 
@@ -523,6 +542,7 @@ var domHandlerObject = {
  * @param callback function callback when all the work has been performed.
  */
 exports.domHandler = function (dom, pageURL, fragment, responseStatus, callback) {
+
     var domHandler = Object.create(domHandlerObject);
 
     domHandler.init(dom, pageURL, fragment, responseStatus, callback);
@@ -535,5 +555,5 @@ exports.domHandler = function (dom, pageURL, fragment, responseStatus, callback)
 
     // launch the whole process.
     domHandler.processScripts();
-
+    
 };
\ No newline at end of file
