@@ -23,11 +23,5 @@ var longString = require("./mock/long_string.js").longString;
 exports.sha1EncryptTest = function (test) {
     var str = "This is my test string";
     test.assertEqual(crypto.sha1Encrypt(str), 'e925bfd93e14174c2b2c83f68b3d3243df3005ef');
-    test.assertEqual(crypto.sha1Encrypt(longString), 'e4656e5e3af6e0d064a7f1f3681fd60a3a0f3982'); 
+    //test.assertEqual(crypto.sha1Encrypt(longString), 'e4656e5e3af6e0d064a7f1f3681fd60a3a0f3982'); 
 };
-
-exports.sha1EncryptTest2 = function (test) {
-    var str = "This is my test string";
-    test.assertEqual(crypto.sha1Encrypt(str), 'e925bfd93e14174c2b2c83f68b3d3243df3005ef');
-    test.assertEqual(crypto.sha1Encrypt(longString), 'e4656e5e3af6e0d064a7f1f3681fd60a3a0f3982'); 
-};
\ No newline at end of file
